@@ -521,3 +521,13 @@ struct loader_envvar_all_filters {
     struct loader_envvar_disable_layers_filter disable_filter;
     struct loader_envvar_filter allow_filter;
 };
+
+struct loader_envvar_id_filter_value {
+    uint32_t begin;
+    uint32_t end;
+};
+
+struct loader_envvar_id_filter {
+    uint32_t count;
+    struct loader_envvar_id_filter_value filters[MAX_ADDITIONAL_FILTERS];
+};
